pyEugene
=====

Eugene Investment & Securities Champion Open Api Python

* Free software: [`MIT`](https://github.com/Choih0401/pyEugene/blob/main/LICENSE)
* Documentation: 

Introduction
------------
pyEugene은 유진투자증권에서 제공하는 Champion Open API를 쉽게 사용하기 위한 비공식 python wrapper입니다.

유진투자증권 Open API를 잘 모르더라도 파이썬만 알고 있다면 쉽게 사용이 가능하도록 제작하는것에 초점을 두었습니다.

아래의 기능들을 잘 모르더라도 충분히 모든 기능을 사용할 수 있습니다. (현재 Tran, Real, Event 부분 제작 완료)
* 유진투자증권에서 제공하는 OCX의 API 구조
* 유진투자증권에서 제공하는 버전처리 프로그램의 작동 구조
* 컨트롤에서 함수 호출을 위한 [`dynamicCall`](https://doc.qt.io/qt-5/qaxbase.html#dynamicCall) 함수 사용

해당 모듈의 사용을 위해서는 32bit 개발 환경이 필요합니다.